/// Gaussian blur for vertical axis
#ifdef GL_ES
precision lowp float;
#endif

uniform sampler2D s_texture;
uniform vec2 u_resolution;

varying vec2 v_uv;

// http://dev.theomader.com/gaussian-kernel-calculator/
#ifdef FS_MOBILE
const float weight3 = 0.06136;
const float weight4 = 0.24477;
const float weight5 = 0.38774;
#else
const float weight1 = 0.000229;
const float weight2 = 0.005977;
const float weight3 = 0.060598;
const float weight4 = 0.241732;
const float weight5 = 0.382928;
#endif

void main(void) {

    vec4 sum = vec4(0.0);
    float blurSize = u_resolution.y;
#ifndef FS_MOBILE
    sum += texture2D(s_texture, vec2(v_uv.x, v_uv.y - 4.0*blurSize)) * weight1;
    sum += texture2D(s_texture, vec2(v_uv.x, v_uv.y - 3.0*blurSize)) * weight2;
#endif
    
    sum += texture2D(s_texture, vec2(v_uv.x, v_uv.y - 2.0*blurSize)) * weight3;
    sum += texture2D(s_texture, vec2(v_uv.x, v_uv.y - blurSize)) * weight4;
    sum += texture2D(s_texture, vec2(v_uv.x, v_uv.y)) * weight5;
    sum += texture2D(s_texture, vec2(v_uv.x, v_uv.y + blurSize)) * weight4;
    sum += texture2D(s_texture, vec2(v_uv.x, v_uv.y + 2.0*blurSize)) * weight3;
    
#ifndef FS_MOBILE
    sum += texture2D(s_texture, vec2(v_uv.x, v_uv.y + 3.0*blurSize)) * weight2;
    sum += texture2D(s_texture, vec2(v_uv.x, v_uv.y + 4.0*blurSize)) * weight1;
#endif
    gl_FragColor = vec4(sum.rgb * sum.a, sum.a * sum.a);
}
