#ifdef GL_ES
precision mediump float;
#endif

// Using cubemapping for best texturing
uniform samplerCube s_texture1;
uniform vec4 u_foregroundColor;
uniform vec4 u_backgroundColor;
uniform vec4 u_borderColor;
// The thickness of white edge on globe
uniform float u_borderWidth;

varying vec3 v_normal;
varying vec3 v_edge_normal;
varying vec3 v_position;

const float FADE_WIDTH = 0.25;

#include "../utils.frag"

void main(void) {
    // The image is grayscale, convert intensity to alpha making oceans transparent
    vec4 tex = textureCube(s_texture1, v_normal);
    float intensity = tex.r;

    // NOTE: u_foregroundColor is not premultipled
    vec4 fg = u_foregroundColor;

    /// cubic out ease to reduce alpha on land area.
    /// New background doesn't look too good when shown through.
    intensity = -intensity * (intensity - 2.0);
    fg.a *= intensity;
    fg = premultiply(fg);

    // NOTE: u_backgroundColor is premultiplied
    tex = mix(u_backgroundColor, fg, fg.a);

    // Create toon edge to sphere by mixing white and keeping alpha 1 close to edge
    // The BORDER defines the width of the border
    float borderIntensity = dot(v_edge_normal, -v_position);
    float edge = clamp(borderIntensity, 0., u_borderWidth) / u_borderWidth;

    vec4 borderColor = mix(u_borderColor, tex, edge);

    // Last do anti-alias effect by fading the edge of sphere
    edge = clamp(borderIntensity, 0., FADE_WIDTH) / FADE_WIDTH;

    gl_FragColor = mix(vec4(0.0,0.0,0.0,0.0), borderColor, edge);

}

