#ifdef GL_ES
precision lowp float;
#endif

#include "precision.sh"

uniform highp mat4 u_modelMatrix[24];  // 4096 max floats on iOS 4S => 1024 uniform vectors.
                                 //  GL_MAX_FRAGMENT_UNIFORM_VECTORS gives only 64...
                                 //  4096 / 4 => 1024 => array size 129 on iOS 4S, but it's slightly slower despite less
                                 //  draw calls. At least with the tested amount of data(620 particles, 4 draws)
uniform lowp vec4 u_backgroundColors[24];
uniform lowp vec4 u_foregroundColors[24];
uniform highp mat4 u_viewMatrix;
uniform highp mat4 u_projectionMatrix;

// NOTE: this has to be highp or integer conversion ends up pointing at wrong data.
attribute highp float a_instanceId;
attribute highp vec3 a_position;
attribute lowp vec2 a_uv;

varying highp vec3 v_position;
varying lowp vec4 v_backgroundColor;
varying lowp vec4 v_foregroundColor;
varying lowp vec2 v_uv;

void main()
{
    int mvpMatrixIndex = int(a_instanceId);

    v_position = a_position.xyz;
    v_backgroundColor = u_backgroundColors[mvpMatrixIndex];
    v_foregroundColor = u_foregroundColors[mvpMatrixIndex];
    v_uv = a_uv;
    gl_Position = (u_projectionMatrix * u_viewMatrix * u_modelMatrix[mvpMatrixIndex]) * vec4(a_position, 1);
}
